=========================================================
WSDL parsing services package for Web Services for Python
=========================================================

.. image:: https://img.shields.io/pypi/pyversions/wstools.svg
        :target: https://pypi.python.org/pypi/wstools/

.. image:: https://img.shields.io/github/license/pycontribs/wstools.svg
        :target: https://pypi.python.org/pypi/wstools/

.. image:: https://img.shields.io/pypi/dm/wstools.svg
        :target: https://pypi.python.org/pypi/wstools/

.. image:: https://img.shields.io/pypi/wheel/wstools.svg
        :target: https://pypi.python.org/pypi/wstools/

------------

.. image:: https://api.travis-ci.org/pycontribs/wstools.svg?branch=develop
        :target: https://travis-ci.org/pycontribs/wstools

.. image:: https://img.shields.io/pypi/status/wstools.svg
        :target: https://pypi.python.org/pypi/wstools/

.. image:: https://img.shields.io/coveralls/pycontribs/wstools.svg
        :target: https://coveralls.io/r/pycontribs/wstools

.. image:: http://api.flattr.com/button/flattr-badge-large.png
        :target: https://flattr.com/submit/auto?user_id=sbarnea&url=https://github.com/pycontribs/wstools&title=Python wstools&language=&tags=github&category=software


General
=======

-  Homepage: https://github.com/pycontribs/wstools
-  Mailing List: https://groups.google.com/forum/#!forum/pycontribs
-  Package: http://pypi.python.org/pypi/wstools/
-  Docs (TBD): http://packages.python.org/wstools

Credits
=======

Companies
---------

\|makinacom\|\_

-  ``Planet Makina Corpus <http://www.makina-corpus.org>``\ \_
-  ``Contact us <mailto:python@makina-corpus.org>``\ \_

.. \|makinacom\| image:: http://depot.makina-corpus.org/public/logo.gif
.. \_makinacom: http://www.makina-corpus.com

Authors
-------

-  Makina Corpus python@makina-corpus.com

Contributors
------------

-  Sorin Sbarnea sorin.sbarnea@gmail.com

.. |Build Status| image:: https://travis-ci.org/kartoch/wstools.svg?branch=master
   :target: https://travis-ci.org/kartoch/wstools
.. |Coverage Status| image:: https://img.shields.io/coveralls/kartoch/wstools.svg
   :target: https://coveralls.io/r/kartoch/wstools?branch=master
